import React from 'react';
import {Link, useNavigate} from 'react-router-dom';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {logout, setLogOut} from '../features/user/userSlice';

const Header = () => {
	const navigate = useNavigate();
	const dispatch = useAppDispatch();
	const {userLoggedIn} = useAppSelector((state) => state.user);

	const handleLogOut = () => {
		const token: string | null = window.sessionStorage.getItem('token');
		dispatch(setLogOut());
		if (token) {
			dispatch(logout(token));
		}
		navigate('/');
	};
	return (
		<div>
			{!userLoggedIn ? (
				<Link
					to={'login'}
					className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
				>
					sign in
				</Link>
			) : (
				<div className="flex justify-between">
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'track-history'}
					>
						Track History
					</Link>
					<a
						onClick={handleLogOut}
						href="#"
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
					>
						Logout
					</a>
				</div>
			)}
		</div>
	);
};

export default Header;
